About
=====

This package provides a python wrapper to the Montage Astronomical Image Mosaic
Engine, including both functions to access individual Montage commands, and
high-level functions to facilitate mosaicking and re-projecting.

Installation and usage instructions are available at http://www.astropy.org/montage-wrapper/

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. image:: https://travis-ci.org/astropy/montage-wrapper.svg?branch=master
  :target: https://travis-ci.org/astropy/montage-wrapper

.. image:: https://coveralls.io/repos/astropy/montage-wrapper/badge.svg
  :target: https://coveralls.io/r/astropy/montage-wrapper
